@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import asyncio
+import logging
 from asyncio import sleep
 from http import HTTPStatus
 from typing import Any, Callable, Coroutine, Generic, Iterable, cast
@@ -40,6 +41,8 @@ from ._reports._printers import PRINTERS, print_report
 from ._validators import AllowedStatusValidator, DefaultValidator, StrictStatusValidator
 from .exceptions import GracyParseFailed
 
+logger = logging.getLogger("gracy")
+
 
 async def _gracefully_throttle(controller: ThrottleController, request_context: GracyRequestContext):
     if isinstance(request_context.active_config.throttling, Unset):
@@ -210,15 +213,17 @@ async def _gracify(
             validators,
         )
 
-    if not retry_result or retry_result.failed:
+    did_request_fail = bool(validation_exc)
+    no_retry_or_retry_also_failed = retry_result is None or retry_result.failed is True
+    if did_request_fail and no_retry_or_retry_also_failed:
         if active_config.log_errors and isinstance(active_config.log_errors, LogEvent):
             process_log_after_request(active_config.log_errors, DefaultLogMessage.ERRORS, request_context, result)
 
-        if isinstance(active_config.retry, GracefulRetry) and active_config.retry.behavior == "pass":
-            must_break = False
+    if isinstance(active_config.retry, GracefulRetry) and active_config.retry.behavior == "pass":
+        must_break = False
 
-        if validation_exc and must_break:
-            raise validation_exc
+    if validation_exc and must_break:
+        raise validation_exc
 
     final_result = _maybe_parse_result(active_config, request_context, result)
 
@@ -238,7 +243,8 @@ class Gracy(Generic[Endpoint]):
         REQUEST_TIMEOUT: float | None = None
         SETTINGS: GracyConfig = DEFAULT_CONFIG
 
-    def __init__(self, replay: GracyReplay | None = None, **kwargs: Any) -> None:
+    def __init__(self, replay: GracyReplay | None = None, DEBUG_ENABLED: bool = False, **kwargs: Any) -> None:
+        self.DEBUG_ENABLED = DEBUG_ENABLED
         self._base_config = cast(GracyConfig, getattr(self.Config, "SETTINGS", DEFAULT_CONFIG))
         self._client = self._create_client(**kwargs)
         self._replay = replay
@@ -264,6 +270,9 @@ class Gracy(Generic[Endpoint]):
         if custom_config:
             active_config = GracyConfig.merge_config(self._base_config, custom_config)
 
+        if self.DEBUG_ENABLED:
+            logger.debug(f"Active Config for {endpoint}: {active_config}")
+
         request_context = GracyRequestContext(
             method, str(self._client.base_url), endpoint, endpoint_args, active_config
         )
